@@ -460,20 +460,18 @@ def main_body(action, filename_parser=None, argv=None):
 def debug_action(action):
     return lambda item: action(item, debug=True)
 
-
-
 def spawn_workers(action, sequence, **kwargs):
-    def uncurry_action(item):
-        return action(item[1], **item[0])
-
+    max_cpus = len(sequence)
     verbose = kwargs['verbose']
     debug = kwargs['debug']
     silent = kwargs['silent']
-    if verbose: print >>sys.stdout, ' '.join(['Using', str(NUM_CPUS),
-                                              'cpus...'])
+    if verbose: print >>sys.stdout, ' '.join(['Using', str(max_cpus),
+                                              'cpu(s)...'])
     if debug: print_debug('Debugging mode enabled')
 
-    if NUM_CPUS == 1:
+    used_cpus = min([NUM_CPUS, max_cpus])
+
+    if used_cpus == 1:
         if debug: print_debug('multiprocessing disabled')
         for item in sequence:
             stdout = action(item, **kwargs)
@@ -483,7 +481,7 @@ def spawn_workers(action, sequence, **kwargs):
             print_debug('WARNING: multiprocessing enabled', os.linesep,
                         'debug output may get mangeled')
         signal.signal(signal.SIGCHLD, signal.SIG_DFL)
-        p = multiprocessing.Pool(processes=NUM_CPUS)
+        p = multiprocessing.Pool(processes=used_cpus)
         results = [p.apply_async(action, (item,), kwargs) for item in sequence]
         stdouts = (result.get() for result in results)
         stdouts_good = itertools.ifilter(lambda x: x is not None, stdouts)
